This is a data-first variant of [plot_futures()] for comparing future projection objects from multiple assessment years. Lines are split at each assessment terminal year: VPA assessment years are drawn as solid lines and future projection years are drawn as dotted lines.

plot_futures2(
  future.list,
  future.name = names(future.list),
  assessment.years = NULL,
  terminal.years = NULL,
  CI_range = c(0.1, 0.9),
  maxyear = NULL,
  minyear = NULL,
  what.plot = c("Recruitment", "biomass", "SSB", "catch", "U", "Fratio"),
  biomass.unit = 1,
  number.unit = 1,
  number.name = "",
  RP_name = c("Btarget", "Blimit", "Bban", "Fmsy", "MSY", "Umsy"),
  Btarget = NA,
  Blimit = NA,
  Bban = NA,
  MSY = NA,
  Umsy = NA,
  is.plot.CIrange = TRUE,
  use_median = FALSE,
  ncol = 2,
  legend.position = "top",
  font.size = 15,
  latest.name = NULL,
  xlab = "漁期年"
)

Arguments

future.list

List of future projection objects.

future.name

Character vector used for scenario labels. Defaults to `names(future.list)`.

assessment.years

Numeric vector of assessment years, in the same order as `future.list`. The terminal year is `assessment.years - 1` unless `terminal.years` is supplied.

terminal.years

Numeric vector of terminal years for each scenario.

CI_range

Numeric vector of two probabilities used for prediction intervals.

maxyear

Maximum year to show. If `NULL`, all years are shown.

minyear

Minimum year to show. If `NULL`, all years are shown.

what.plot

Statistics to plot. See [plot_futures()].

biomass.unit

Unit divisor for biomass and catch values.

number.unit

Unit divisor for recruitment values.

number.name

Unit name for recruitment.

RP_name

Labels for reference points: Btarget, Blimit, Bban, Fmsy, MSY, and Umsy.

Btarget, Blimit, Bban

Biomass reference points.

MSY, Umsy

Catch and exploitation-rate reference points.

is.plot.CIrange

Logical. If `TRUE`, draw prediction interval ribbons.

use_median

Logical. If `TRUE`, draw medians instead of means.

ncol

Number of facet columns.

legend.position

Legend position passed to [theme_SH()].

font.size

Base font size.

latest.name

Scenario to draw with a thicker line. Defaults to the first future scenario.

xlab

X-axis label.

Value

A ggplot object. The plotting data are stored in `attr(plot, "plot_data")`.