plot_futures2.RdThis is a data-first variant of [plot_futures()] for comparing future projection objects from multiple assessment years. Lines are split at each assessment terminal year: VPA assessment years are drawn as solid lines and future projection years are drawn as dotted lines.
plot_futures2(
future.list,
future.name = names(future.list),
assessment.years = NULL,
terminal.years = NULL,
CI_range = c(0.1, 0.9),
maxyear = NULL,
minyear = NULL,
what.plot = c("Recruitment", "biomass", "SSB", "catch", "U", "Fratio"),
biomass.unit = 1,
number.unit = 1,
number.name = "",
RP_name = c("Btarget", "Blimit", "Bban", "Fmsy", "MSY", "Umsy"),
Btarget = NA,
Blimit = NA,
Bban = NA,
MSY = NA,
Umsy = NA,
is.plot.CIrange = TRUE,
use_median = FALSE,
ncol = 2,
legend.position = "top",
font.size = 15,
latest.name = NULL,
xlab = "漁期年"
)List of future projection objects.
Character vector used for scenario labels. Defaults to `names(future.list)`.
Numeric vector of assessment years, in the same order as `future.list`. The terminal year is `assessment.years - 1` unless `terminal.years` is supplied.
Numeric vector of terminal years for each scenario.
Numeric vector of two probabilities used for prediction intervals.
Maximum year to show. If `NULL`, all years are shown.
Minimum year to show. If `NULL`, all years are shown.
Statistics to plot. See [plot_futures()].
Unit divisor for biomass and catch values.
Unit divisor for recruitment values.
Unit name for recruitment.
Labels for reference points: Btarget, Blimit, Bban, Fmsy, MSY, and Umsy.
Biomass reference points.
Catch and exploitation-rate reference points.
Logical. If `TRUE`, draw prediction interval ribbons.
Logical. If `TRUE`, draw medians instead of means.
Number of facet columns.
Legend position passed to [theme_SH()].
Base font size.
Scenario to draw with a thicker line. Defaults to the first future scenario.
X-axis label.
A ggplot object. The plotting data are stored in `attr(plot, "plot_data")`.